import argparse
from blueness import module
from abcli import VERSION, NAME
from abcli.plugins.ssm.functions import get_secret, put_secret, rm_secret
from abcli.logger import logger
from blueness.argparse.generic import sys_exit

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME, description=f"{NAME}-{VERSION}")
parser.add_argument(
    "task",
    type=str,
    default="",
    help="get|put|rm",
)
parser.add_argument(
    "--description",
    type=str,
    default="",
)
parser.add_argument(
    "--name",
    type=str,
)
parser.add_argument(
    "--value",
    type=str,
)
args = parser.parse_args()

success = False
if args.task == "get":
    success, value = get_secret(args.name)

    if success:
        print(value)
elif args.task == "put":
    success, _ = put_secret(
        args.name,
        args.value,
        args.description,
    )
elif args.task == "rm":
    success, _ = rm_secret(args.name)
else:
    success = None

sys_exit(logger, NAME, args.task, success, log=False)



import os

NAME = "abcli"

ICON = "🪄"

DESCRIPTION = f"{ICON} a language to speak AI."

VERSION = "9.361.1"

REPO_NAME = "awesome-bash-cli"

MARQUEE = "https://github.com/kamangir/awesome-bash-cli/raw/main/assets/marquee.png"


def fullname() -> str:
    abcli_git_branch = os.getenv("abcli_git_branch", "")
    return "{}-{}{}".format(
        NAME,
        VERSION,
        f"-{abcli_git_branch}" if abcli_git_branch else "",
    )



import argparse
import cv2

from blueness import module
from blueness.argparse.generic import sys_exit
from blue_objects import file

from abcli import NAME
from abcli.logger import logger


NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    default="",
    help="resize|size_of",
)
parser.add_argument(
    "--filename",
    type=str,
)
parser.add_argument(
    "--scale",
    type=float,
)
parser.add_argument(
    "--size",
    type=str,
    help="widthxheight",
)
args = parser.parse_args()

success = False
if args.task == "resize":
    (width, height) = (int(thing) for thing in args.size.split("x"))

    success, image = file.load_image(args.filename)

    if success:
        success = file.save_image(
            args.filename,
            cv2.resize(
                image,
                (width, height),
            ),
        )

    if success:
        logger.info(f"{NAME}.resize({width},{height}): {args.filename}")
elif args.task == "size_of":
    success, image = file.load_image(args.filename)

    if success:
        print(
            "{}x{}".format(
                2 * int(image.shape[1] / 2 / args.scale),
                2 * int(image.shape[0] / 2 / args.scale),
            )
        )
else:
    success = None

sys_exit(logger, NAME, args.task, success)
